==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/outputs/GetMarketplaceSubscriptionResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Azure Resource Manager resource envelope.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property marketplaceSubscriptionProperties [Required] Additional attributes of the entity.
 * @property name The name of the resource
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetMarketplaceSubscriptionResult(
    public val id: String,
    public val marketplaceSubscriptionProperties: MarketplaceSubscriptionResponse,
    public val name: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.machinelearningservices.outputs.GetMarketplaceSubscriptionResult):
            GetMarketplaceSubscriptionResult = GetMarketplaceSubscriptionResult(
            id = javaType.id(),
            marketplaceSubscriptionProperties = javaType.marketplaceSubscriptionProperties().let({ args0 ->
                com.pulumi.azurenative.machinelearningservices.kotlin.outputs.MarketplaceSubscriptionResponse.Companion.toKotlin(args0)
            }),
            name = javaType.name(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/outputs/GetMarketplaceSubscriptionResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Azure Resource Manager resource envelope.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property marketplaceSubscriptionProperties [Required] Additional attributes of the entity.
 * @property name The name of the resource
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetMarketplaceSubscriptionResult(
    public val id: String,
    public val marketplaceSubscriptionProperties: MarketplaceSubscriptionResponse,
    public val name: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.machinelearningservices.outputs.GetMarketplaceSubscriptionResult): GetMarketplaceSubscriptionResult = GetMarketplaceSubscriptionResult(
            id = javaType.id(),
            marketplaceSubscriptionProperties = javaType.marketplaceSubscriptionProperties().let({ args0 ->
                com.pulumi.azurenative.machinelearningservices.kotlin.outputs.MarketplaceSubscriptionResponse.Companion.toKotlin(args0)
            }),
            name = javaType.name(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}
